---
title: WaylonWalker.com 
codeUrl: https://github.com/WaylonWalker/waylonwalker.com/
url: https://waylonwalker.com

---

[![Waylonwalker.com home page](/waylonwalker.com.webp)](https://waylonwalker.com)

This Waylon Walker's personal blog where he is learning in public.  Posting
about topics such as linux, vim, python, and kedro.  Flexing just a bit, after
writing content on the domain since 2017 it is achieving  15K clicks from
google every 28 days, 36 top 3 ranked keywords, and 2,400 top 10 ranked keywords.


[![Waylonwalker.com post](/waylonwalker.com_markata-configure-head.webp)](https://waylonwalker.com/markata-configure-head/)

A typical post has a header that is screenshot as the og image for display on
social platforms using selenium.  The overall theme holds similar to the home
and feeds pages.  With a large dark background image of repeating W's.


[![Waylonwalker.com feed](/waylonwalker.com_archive.webp)](https://waylonwalker.com/archive/)

Waylonwalker.com has several feeds running, but the most prominant one that is
shared in the navigation bar is the
[archive](https://waylonwalker.com/archive).  The feed itself has an RGB
backlight inspired yellow and purple glow around it.



